plot_latlon_bw = function(lon,lat,field,nbreaks=10,plot.legend=TRUE,title.say=NULL,
    lmaskzero=TRUE,shrinkdomain=FALSE,plot.continents=TRUE,force.pm=FALSE,
    cbar.list=NULL,suppress.axislab=FALSE,rotate.land=FALSE,labelFontSize=1.5) {
	
## GENERATES SPATIAL PLOTS ON A GLOBE WITH SUPERIMPOSED CONTINENTAL MAP
## LON[NLON]: LONGITUDE COORDINATES
## LAT[NLAT]: LATITUDE COORDINATES
## NBREAKS: NUMBER OF BREAK POINTS FOR COLOR BAR (DEFAULT=10)
## PLOT.LEGEND: =TRUE TO PLOT THE LEGEND, =FALSE TO SUPPRESS LEGEND
## TITLE.SAY: CHARACTER STRING FOR THE TITLE
## LMASKZERO: =TRUE TO SET ZERO TO 'WHITE', OTHERWISE SET TO 'GREY'
## SHRINKDOMAIN: =TRUE TO RE-ADJUST LAT/LON TO SHOW ONLY DEFINED POINTS
## PLOT.CONTINENTS: = TRUE TO PLOT CONTINENTS, OTHERWISE CONTINENTS ARE NOT PLOTTED
## FORCE.PM: FORCE COLOR BAR TO RANGE FROM NEGATIVE TO POSITIVE VALUES

all.na        = all(is.na(field))
all.constant  = (var(as.numeric(field),na.rm=TRUE)/max(abs(field),na.rm=TRUE) <= 1.e-15 ) & !all.na
nbreaks.half  = floor(nbreaks/2)

#####################################################################
## IMPORT COLOR BAR PARAMETERS
#####################################################################
if (!is.null(cbar.list)) {
	plot.cols   = cbar.list$plot.cols
	plot.breaks = cbar.list$plot.breaks
}

#####################################################################
## IF FIELD IS ALL NAS, MAKE UP DATA SO THAT A BLANK PLOT IS FORMED
#####################################################################
if (all.na) {
	dim(field) = c(length(lon),length(lat))
	field[1,1] = 0
	plot.breaks = c(-1,0,1)
	plot.cols   = c("white","white")	

} else if (is.null(cbar.list)) {
	#####################################################################
	## IF FIELD IS A CONSTANT, THEN MAKE UP A RANGE OF DATA
	#####################################################################
	if ( all.constant) {
		constant.value = mean(as.numeric(field),na.rm=TRUE)
		if (constant.value == 0 ) {
			plot.breaks = seq(from=0,to=1,length.out=nbreaks.half) 
		} else { 
			plot.breaks = seq(from = 0, to = constant.value,length.out = nbreaks.half)
			plot.breaks[nbreaks.half] = plot.breaks[nbreaks.half]*1.001
		}
	} else {
		plot.breaks = pretty(abs(field),n=floor(nbreaks.half))
	}
	
	#####################################################################
	## GENERATE SYMMETRIC BREAKS ABOUT 0, OR INSERT ZERO IN THE BREAKS
	#####################################################################
	l.pm   = min(field,na.rm=TRUE)*max(field,na.rm=TRUE) < 0
	if (l.pm | force.pm) {
		plot.breaks = c(-rev(plot.breaks),plot.breaks)
		plot.breaks = plot.breaks[ plot.breaks != 0 ] ; # get rid of zero break points
	} else {
		plot.breaks = c(0,plot.breaks)
	}
	plot.breaks = sort(union(plot.breaks,plot.breaks)); #get rid of redundant breaks
	
	#####################################################################
	## GENERATE COLORS
	#####################################################################
	if (!all.na & is.null(cbar.list)) {
		if (l.pm | force.pm) {
			nb          = length(plot.breaks)
			npos        = sum(plot.breaks > 0)
			plot.cols   = colorRampPalette(c('grey','grey30'),space='rgb')(npos-1)
			plot.cols   = c(rep('white',nb-npos),plot.cols)
		} else {
			nb          = length(plot.breaks)
			plot.cols   = colorRampPalette(c('grey','grey30'),space='rgb')(nb-1)			
		}
	}

	
	#####################################################################
	## SET ZERO INTERVAL TO WHITE IF DESIRED
	#####################################################################
	if (is.null(cbar.list)) {
		nb                 = length(plot.breaks)
		break.include.zero = plot.breaks[1:(nb-1)] <=0 & plot.breaks[2:nb] >= 0
		plot.cols[break.include.zero] = 'white'	
	}
}


#####################################################################
## DEFINE DUMMY ARRAY FOR PLOTTING
#####################################################################
plot.var = array(field,dim=c(length(lon),length(lat)))

#####################################################################
## REVERSE LATITUDES IF THEY GO FROM NORTH TO SOUTH
#####################################################################
if ( lat[2] - lat[1] < 0 ) {
	plot.var = plot.var[,length(lat):1]
	lat.say  = lat[length(lat):1]
	print('latitudes reversed')
} else {
	lat.say  = lat
}

#####################################################################
## ROTATE TO AVOID CUTTING ACROSS LAND MASSES
#####################################################################
if (rotate.land & lon[1] >= 0 ) {
	nlon     = length(lon)
	nst      = max(which(lon <= 180))
	npic     = c((nst+1):nlon,1:nst)
	plot.var = plot.var[npic,]
	lon      = c(lon[(nst+1):nlon] - 360,lon[1:nst])
}

#####################################################################
## SHRINK DOMAIN IF DATA IS MISSING 
#####################################################################
if (suppress.axislab) {xaxt='n';yaxt='n'} else {xaxt='s';yaxt='s'}
if (shrinkdomain) {
	good  = which(!is.na(plot.var),arr.ind=TRUE)
	xpic  = range(good[,'row'])
	ypic  = range(good[,'col'])
	xlim = lon[xpic]; ylim = lat.say[ypic]
	image(lon,lat.say,plot.var,col=plot.cols,breaks=plot.breaks,xlab="",ylab="",xlim=xlim,ylim=ylim,xaxt=xaxt,yaxt=yaxt)
	contour(lon,lat.say,plot.var,levels=plot.breaks,xlab="",ylab="",xlim=xlim,ylim=ylim,xaxt=xaxt,yaxt=yaxt,add=TRUE,labcex=1.3)
} else {
	xlim = range(lon); ylim = range(lat.say)
	image(lon,lat.say,plot.var,col=plot.cols,breaks=plot.breaks,xlab="",ylab="",xaxt=xaxt,yaxt=yaxt,xlim=xlim,ylim=ylim)
	contour(lon,lat.say,plot.var,levels=plot.breaks,xlab="",ylab="",xaxt=xaxt,yaxt=yaxt,add=TRUE,xlim=xlim,ylim=ylim,labcex=1.3)
}

#####################################################################
## ADD DOTS FOR NEGATIVE REGIONS
#####################################################################
lon.all = rep(lon,length(lat))
lat.all = rep(lat.say,each=length(lon))

nneg         = sum( plot.breaks < 0)
grey.scale   = colorRampPalette(c('black','grey'),space='rgb')(nneg)
cex.scale    = seq(from=0.7,to=0.3,length.out=nneg)		


for ( n in 1:length(plot.breaks)) {
	if ( n== 1) {
		lplot.point = as.logical(plot.var < plot.breaks[1] & plot.breaks[n] < 0 )
	} else {
		lplot.point = as.logical(plot.var >= plot.breaks[n-1] & plot.var < plot.breaks[n] & plot.breaks[n] < 0)
	}
	lplot.point[is.na(lplot.point)] = FALSE		
	if (!all(!lplot.point)) {
		lon.pic = lon.all[lplot.point]
		lat.pic = lat.all[lplot.point]
		par(new=TRUE)
		plot(lon.pic,lat.pic,pch=4,col=grey.scale[n],xlim=xlim,ylim=ylim,xaxs='i',yaxs='i',xlab='',ylab='',axes=FALSE,cex=cex.scale[n])
	}
}
contour(lon,lat.say,plot.var,levels=plot.breaks,xlab="",ylab="",xaxt=xaxt,yaxt=yaxt,add=TRUE,xlim=xlim,ylim=ylim,lwd=2,labcex=1.3)


#####################################################################
## ADD COLOR BAR 
#####################################################################
if (plot.legend) addMapLegend(cutVector=plot.breaks,colourVector=plot.cols,legendLabels='all',
   legendMar=5,horizontal=TRUE,labelFontSize=labelFontSize,catMethod='pretty')

#####################################################################
## ADD TITLE
#####################################################################
if (!is.null(title.say)) title(main=as.character(title.say))

#####################################################################
## ADD CONTINENTS
#####################################################################
if (plot.continents) if ( lon[1] < 0 ) map('world',interior=FALSE,add=TRUE) else map('world2',interior=FALSE,add=TRUE)
if (plot.continents) map('lakes',add=TRUE,fill=TRUE,col='white',boundary='black') 


#####################################################################
## OUTPUT PLOTTING PARAMETERS
#####################################################################
list(plot.breaks=plot.breaks,plot.cols=plot.cols)


}